#
# spec file for package rioterm
#
# Copyright (c) 2023 Nicolas Lorin <androw95220@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rioterm
Version:        0.0.19
Release:        bp156.1.8
Summary:        A hardware-accelerated GPU terminal emulator powered by WebGPU
License:        MIT
URL:            https://raphamorim.io/rio/
Source0:        rio-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
Requires:       rioterm-terminfo
BuildRequires:  cargo-packaging
BuildRequires:  cmake
BuildRequires:  freetype-devel
BuildRequires:  libxcb-devel
BuildRequires:  libxkbcommon-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  python311
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  ncurses-devel
BuildRequires:  update-desktop-files

%description
A hardware-accelerated GPU terminal emulator powered by WebGPU, focusing to run in desktops and browsers.

%package terminfo
Summary:        Terminfo for %{name}
Supplements:    (%{name})
BuildArch:      noarch

%description terminfo
The official terminfo for rioterm.

%prep
%setup -a1 -qn rio-%{version}
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build} --no-default-features --features=x11,wayland
tic -e rio -x -o terminfo misc/rio.terminfo

%install
mkdir -p "%{buildroot}%{_bindir}"
install -D -m 0755 target/release/rio %{buildroot}%{_bindir}/rio
install -D -m 0644 terminfo/r/rio %{buildroot}/usr/share/terminfo/r/rio
install -D -m 0644 misc/rio.desktop %{buildroot}/%{_datadir}/applications/rio.desktop
install -D -m 0644 misc/logo.svg %{buildroot}/%{_datadir}/pixmaps/rio.svg

# install desktop file
%suse_update_desktop_file rio

%files
%license LICENSE
%{_bindir}/rio
%{_datadir}/applications/rio.desktop
%{_datadir}/pixmaps/rio.svg

%files terminfo
/usr/share/terminfo/r/rio

%changelog
* Tue Sep 19 2023 androw95220@gmail.com
- Update to version 0.0.19:
  * wrap up post release 0.0.19
  * update CHANGELOG.md
  * update package versions
  * prepare 0.0.19
  * disable menu macos
  * update image example
  * use TriangleList as PrimitiveTopology
  * update config with undercased
  * update fmt dynamic change
  * dynamic background color
  * remove renderable trait
  * update config tests
  * implementation of image background without opacity
  * work in progress image rendering
  * compute fg/bg colors
  * new docs
  * teach sugarloaf how render layer image and start docs 2.0
  * feat: option for ignoring theme foreground selection color (#227)
  * remove backspace with modifierState
  * remove DISAMBIGUATE_KEYS from arrows bindings
  * split update counter per x/y on settings menu
  * update sugarloaf api for wasm32
  * map the rest of the configuration
  * write configuration from settings UI
  * reuse font reference in all screens (yey) and link font faces to settings
  * ignore loader on wasm32
  * incluse font loader to sugarloaf with normalization of the name
  * font loader
  * docs: add opensuse linux package (#224)
  * use fixed font width
  * update fmt teleypewriter
  * treat errors from teletypewriter
  * turn off testing settings route
  * update character position for column whenever has a selection (related #182)
  * remove settings representation
  * settings ui work in progress
  * remove x icon on error ui
  * update fmt for &error.report
  * update window dead context
  * create dead_context and report now is splitted in two levels warning and error (closes #212)
  * update env variables
  * read from working_directory in flatpak
  * use spawn as default for flatpak
  * flatpak support
  * Rename Regular window mode to Windowed (#219)
  * custom impl Default for Window
  * add window mode default for mode
  * fmt window rio-config
  * add window.rs in rio-config
  * new window API that allow configure maximized or fullscreen (closes #215)
  * fmt unix/mod.rs
  * if runs inside a flatpak sandbox retrieve /bin/zsh from flatpak-spawn
  * docs: add alpine linux package (#218)
  * move style code back
  * teletypewriter validate if is a flatpak sandbox to retrieve SHELL
  * remove duplicate get_pw_entry calls
  * retrieve-shell-outside-box-for-flatpak
  * Add navigation Plain mode (closes #213)
  * demo/emacs: better screenshot (#211)
  * disable NavigationHasChanged warn (todo for next release)
  * fix: change package name from rio to rioterm (#210)
  * update changelog
  * update Cargo.toml files and published a rc version to crates.io
  * has_regained_focus redraw window for idle windows
  * update rules for blinking cursor
  * partial support to blinking cursor (has few incosistencies yet like selection and VI mode switchs
  * add font name variant for cascadia code
  * fix breadcrumbs id
  * error UI for fonts
  * use crate::ui::Error
  * update target_arch for sugarloaf
  * minor fixes for docs styles
  * linux doesn't use .0 since is font_arc straight
  * clear comments
  * implementation of event for UI component that shows the error of configuration file (closes #168)
  * update lock file
  * make docs and docs-prod
  * add jekyll-minifier
  * update CHANGELOG.md
  * migrated font-kit to fontdb
  * move scripts to inside misc folder
  * rename rio_proc_macros to rio-proc-macro and reuse version from workspace
  * merge config and colors into rio-config
  * move create toolbar to ui::appkit::mod
  * remove silkscreen
  * update images
  * update website wip
  * update docs
  * add top to other sections
  * go to top button docs
  * update docs (on-going)
  * update ui mod (code originally came from madsmtm/menubar
  * ui kit
  * add initial support to menubar
  * block rgba16float to prevent nvidia driver to enable hdr (#209)
  * adaptive theme support (close #207)
  * correct std::fmt::Display for Breadcrumb
  * update settings function
  * provide settings from builder
  * finish layout UI for settings
  * colors and config load version from workspaces
  * use workspace
  * update cargo.toml
  * copa 0.12
  * update changelog
  * implemented ScrollPageUp, ScrollPageDown, ScrollHalfPageUp, ScrollHalfPageDown, ScrollToTop, ScrollToBottom, ScrollLineUp, ScrollLineDown (close #206)
  * support fonts.family to overwrite all other font families
  * create_native_tab only for macos
  * fix shift key with arrow
  * update CHANGELOG.md
  * connect router with windows and native tabs
  * welcome screen
  * use .to_string
  * update identation
  * cover legacy modifiers
  * wip settings ui
  * update styles for settings ui
  * mockup settings UI
  * introduce Router
  * fix literal with an empty format string
  * release on enter
  * update message config
  * add assistant
  * NativeTab is MacOS default now
  * add errors to assistant if have configuration error whenever updating the config
  * assistant UI
  * corcovado use Rc instead of Arc due to Sync trait
  * update lint for rust 1.72
  * Update CHANGELOG.md
  * update rust and fix 'Backspace' keypress triggers Ctrl+h keybinding in Zellij (closes #197)
  * update CHANGELOG.md
  * implement TERM_PROGRAM and TERM_PROGRAM_VERSION variables
  * chore: fix typo (#199)
  * only apply check for native tab deadzone in cursor updates
  * Whenever native tabs is on disable macos deadzone logic
  * docs: update the link for Arch Linux package (#195)
* Sun Sep 10 2023 androw95220@gmail.com
- Update to version 0.0.18~0:
  * update to 0.0.18
  * 0.0.18
  * fix delete key
  * fix breadcrumb navigation crash
  * fix breadcrumb navigation (closes #193)
  * fix wasmbuild with font spec
  * update docs regarding release
  * prepare 0.0.17 release
  * update repology badge
  * update font API
* Sun Sep 10 2023 Nicolas Lorin <androw95220@gmail.com>
  new package-
